@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.8 2000/12/08 05:05:42 jleach Exp $ */
+/* $Id: gweather-dialog.c,v 1.9 2001/06/17 18:27:59 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -99,6 +99,7 @@ void gweather_dialog_create (void)
       gtk_widget_set_usize (gweather_dialog, 570, 440);
   else
       gtk_widget_set_usize (gweather_dialog, 590, 340);
+
   gtk_window_set_policy (GTK_WINDOW (gweather_dialog), FALSE, FALSE, FALSE);
   gnome_dialog_close_hides(GNOME_DIALOG(gweather_dialog), TRUE);
 
@@ -400,6 +401,7 @@ void gweather_dialog_display_toggle (void)
 void gweather_dialog_update (void)
 {
     const gchar *forecast;
+    GdkFont* detailed_forecast_font = gdk_fontset_load ( "fixed" );
 
     /* Check for parallel network update in progress */
     if(gweather_info == NULL)
@@ -429,12 +431,12 @@ void gweather_dialog_update (void)
     gtk_text_forward_delete(GTK_TEXT(forecast_text), gtk_text_get_length(GTK_TEXT(forecast_text)));
     forecast = weather_info_get_forecast(gweather_info);
     if (forecast) {
-        gtk_text_insert(GTK_TEXT(forecast_text), NULL, NULL, NULL, forecast, strlen(forecast));
+        gtk_text_insert(GTK_TEXT(forecast_text), detailed_forecast_font, NULL, NULL, forecast, strlen(forecast));
     } else {
         if (gweather_pref.detailed)
-            gtk_text_insert(GTK_TEXT(forecast_text), NULL, NULL, NULL, _("Detailed forecast not available for this location.\nPlease try the state forecast; note that IWIN forecasts are available only for US cities."), -1);
+            gtk_text_insert(GTK_TEXT(forecast_text), detailed_forecast_font, NULL, NULL, _("Detailed forecast not available for this location.\nPlease try the state forecast; note that IWIN forecasts are available only for US cities."), -1);
         else
-            gtk_text_insert(GTK_TEXT(forecast_text), NULL, NULL, NULL, _("State forecast not available for this location.\nPlease try the detailed forecast; note that IWIN forecasts are available only for US cities."), -1);
+            gtk_text_insert(GTK_TEXT(forecast_text), detailed_forecast_font, NULL, NULL, _("State forecast not available for this location.\nPlease try the detailed forecast; note that IWIN forecasts are available only for US cities."), -1);
     }
 
     /* Update radar map */
