@@ -28,6 +28,10 @@ static const gchar *cpu_texts [4] = {
     N_("User"),  N_("System"),   N_("Nice"),  N_("Idle")
 };
 
+static const gchar *page_texts [3] = {
+    N_("In"),  N_("Out"), N_("Idle")
+};
+
 static const gchar *mem_texts [4] =  {
     N_("Other"), N_("Shared"), N_("Buffers"), N_("Free")
 };
@@ -37,7 +41,7 @@ static const gchar *swap_texts [2] = {
 };
 
 static const gchar *net_texts [4] = {
-    N_("SLIP"), N_("PPP"), N_("ETH"), N_("WVLAN"), N_("Other"),
+    N_("SLIP"), N_("PPP"), N_("ETH"), N_("Other"),
 };
 
 static const gchar *loadavg_texts [2] = {
@@ -49,6 +53,11 @@ static const gchar *cpu_color_defs [4] = {
     "#afffafffafff", "#000000000000"
 };
 
+static const gchar *page_color_defs [3] = {
+    "#ffffffff4fff", "#afffafffafff",
+    "#000000000000"
+};
+
 static const gchar *mem_color_defs [4] = {
     "#bfffbfff4fff", "#efffefff4fff",
     "#afffafffafff", "#00008fff0000"
@@ -58,10 +67,9 @@ static const gchar *swap_color_defs [4] = {
     "#cfff5fff5fff", "#00008fff0000"
 };
 
-static const gchar *net_color_defs [5] = {
+static const gchar *net_color_defs [4] = {
     "#64009500e0e0", "#d300d300d300", 
-    "#00008fff0000", "#ffffffff4fff",
-    "#9573f121ffff"
+    "#00008fff0000", "#ffffffff4fff"
 };
 
 static const gchar *loadavg_color_defs [2] = {
@@ -81,6 +89,8 @@ make_new_applet (const gchar *goad_id)
 	return make_netload_applet (goad_id);
     else if (strstr (goad_id, "multiload_loadavg_applet"))
 	return make_loadavg_applet (goad_id);
+    else if (strstr (goad_id, "multiload_pageload_applet"))
+	return make_pageload_applet (goad_id);
     else
 	return make_cpuload_applet (goad_id);
 }
@@ -146,6 +156,20 @@ main (int argc, char **argv)
     multiload_properties.cpuload.adj_data [0] = 500;
     multiload_properties.cpuload.adj_data [1] = 40;
 
+    multiload_properties.pageload.n = 3;
+    multiload_properties.pageload.name = "pageload";
+#ifdef ENABLE_NLS
+    {
+	int i;
+	for (i=0;i<4;i++) page_texts[i]=_(page_texts[i]);
+    }
+#endif
+    multiload_properties.pageload.texts = page_texts;
+    multiload_properties.pageload.color_defs = page_color_defs;
+    multiload_properties.pageload.adj_data [0] = 500;
+    multiload_properties.pageload.adj_data [1] = 40;
+    multiload_properties.pageload.adj_data [2] = 40;
+
     multiload_properties.memload.n = 4;
     multiload_properties.memload.name = "memload";
 #ifdef ENABLE_NLS
@@ -177,7 +201,7 @@ main (int argc, char **argv)
 #ifdef ENABLE_NLS
     {
         int i;
-        for (i=0;i<5;i++) net_texts[i]=_(net_texts[i]);
+        for (i=0;i<3;i++) net_texts[i]=_(net_texts[i]);
     }
 #endif
     multiload_properties.netload.texts = net_texts;
@@ -209,6 +233,7 @@ main (int argc, char **argv)
     /* Add property objects. */
 
     ADD_PROPERTIES (LoadGraph, cpuload);
+    ADD_PROPERTIES (LoadGraph, pageload);
     ADD_PROPERTIES (LoadGraph, memload);
     ADD_PROPERTIES (LoadGraph, swapload);
     ADD_PROPERTIES (LoadGraph, netload);
@@ -222,18 +247,22 @@ main (int argc, char **argv)
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
     c = g_list_nth (multiload_property_object_list, 1);
-    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Memory Load"));
+    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Page Load"));
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
     c = g_list_nth (multiload_property_object_list, 2);
-    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Swap Load"));
+    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Memory Load"));
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
     c = g_list_nth (multiload_property_object_list, 3);
-    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Net Load"));
+    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Swap Load"));
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
     c = g_list_nth (multiload_property_object_list, 4);
+    ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Net Load"));
+    gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
+
+    c = g_list_nth (multiload_property_object_list, 5);
     ((GnomePropertyObject *) c->data)->label = gtk_label_new (_("Load Average"));
     gtk_widget_ref (((GnomePropertyObject *) c->data)->label);
 
@@ -243,7 +272,7 @@ main (int argc, char **argv)
     applet_factory_new ("multiload_applet", NULL, applet_start_new_applet);
 
     /* Only do if factory wasn't requested. */
-    if(strcmp(goad_id, "multiload_applet"))
+    if(goad_id && strcmp(goad_id, "multiload_applet"))
 	make_new_applet(goad_id);
 
     applet_widget_gtk_main ();
